Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src rename struct ext2fs_dinode attribute e2di_dacl to correct



details:   https://anonhg.NetBSD.org/src/rev/8665c3c03168
branches:  trunk
changeset: 816976:8665c3c03168
user:      jdolecek <jdolecek%NetBSD.org@localhost>
date:      Thu Aug 04 17:43:47 2016 +0000

description:
rename struct ext2fs_dinode attribute e2di_dacl to correct
e2di_size_high; even Linux ext2 filesystem code actually uses it
unconditionally this way and ext4 code finally also calls it that way
in their struct definition too; if there was any trace of this for other
purpose it's long gone

diffstat:

 sbin/fsck_ext2fs/inode.c       |   8 ++++----
 sbin/newfs_ext2fs/mke2fs.c     |  10 +++++-----
 sys/ufs/ext2fs/ext2fs.h        |   4 ++--
 sys/ufs/ext2fs/ext2fs_bswap.c  |   6 +++---
 sys/ufs/ext2fs/ext2fs_dinode.h |   4 ++--
 sys/ufs/ext2fs/ext2fs_inode.c  |   8 ++++----
 sys/ufs/ufs/inode.h            |   4 +---
 7 files changed, 21 insertions(+), 23 deletions(-)

diffs (184 lines):

diff -r 35b60e03d434 -r 8665c3c03168 sbin/fsck_ext2fs/inode.c
--- a/sbin/fsck_ext2fs/inode.c  Thu Aug 04 17:07:23 2016 +0000
+++ b/sbin/fsck_ext2fs/inode.c  Thu Aug 04 17:43:47 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: inode.c,v 1.36 2013/06/23 07:28:36 dholland Exp $      */
+/*     $NetBSD: inode.c,v 1.37 2016/08/04 17:43:47 jdolecek Exp $      */
 
 /*
  * Copyright (c) 1980, 1986, 1993
@@ -58,7 +58,7 @@
 #if 0
 static char sccsid[] = "@(#)inode.c    8.5 (Berkeley) 2/8/95";
 #else
-__RCSID("$NetBSD: inode.c,v 1.36 2013/06/23 07:28:36 dholland Exp $");
+__RCSID("$NetBSD: inode.c,v 1.37 2016/08/04 17:43:47 jdolecek Exp $");
 #endif
 #endif /* not lint */
 
@@ -141,7 +141,7 @@
        u_int64_t size = fs2h32(dp->e2di_size);
 
        if ((fs2h16(dp->e2di_mode) & IFMT) == IFREG)
-               size |= (u_int64_t)fs2h32(dp->e2di_dacl) << 32;
+               size |= (u_int64_t)fs2h32(dp->e2di_size_high) << 32;
        if (size > INT32_MAX)
                (void)setlarge();
        return size;
@@ -151,7 +151,7 @@
 inossize(struct ext2fs_dinode *dp, u_int64_t size)
 {
        if ((fs2h16(dp->e2di_mode) & IFMT) == IFREG) {
-               dp->e2di_dacl = h2fs32(size >> 32);
+               dp->e2di_size_high = h2fs32(size >> 32);
                if (size > INT32_MAX)
                        if (!setlarge())
                                return;
diff -r 35b60e03d434 -r 8665c3c03168 sys/ufs/ext2fs/ext2fs.h
--- a/sys/ufs/ext2fs/ext2fs.h   Thu Aug 04 17:07:23 2016 +0000
+++ b/sys/ufs/ext2fs/ext2fs.h   Thu Aug 04 17:43:47 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: ext2fs.h,v 1.39 2016/08/03 21:53:02 jdolecek Exp $     */
+/*     $NetBSD: ext2fs.h,v 1.40 2016/08/04 17:43:48 jdolecek Exp $     */
 
 /*
  * Copyright (c) 1982, 1986, 1993
@@ -318,7 +318,7 @@
  * - EXT2F_ROCOMPAT_SPARSESUPER
  *    superblock backups stored only in cg_has_sb(bno) groups
  * - EXT2F_ROCOMPAT_LARGEFILE
- *    use e2di_dacl in struct ext2fs_dinode to store 
+ *    use e2di_size_high in struct ext2fs_dinode to store 
  *    upper 32bit of size for >2GB files
  * - EXT2F_INCOMPAT_FTYPE
  *    store file type to e2d_type in struct ext2fs_direct
diff -r 35b60e03d434 -r 8665c3c03168 sys/ufs/ext2fs/ext2fs_bswap.c
--- a/sys/ufs/ext2fs/ext2fs_bswap.c     Thu Aug 04 17:07:23 2016 +0000
+++ b/sys/ufs/ext2fs/ext2fs_bswap.c     Thu Aug 04 17:43:47 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: ext2fs_bswap.c,v 1.21 2016/08/03 21:53:02 jdolecek Exp $       */
+/*     $NetBSD: ext2fs_bswap.c,v 1.22 2016/08/04 17:43:48 jdolecek Exp $       */
 
 /*
  * Copyright (c) 1997 Manuel Bouyer.
@@ -26,7 +26,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ext2fs_bswap.c,v 1.21 2016/08/03 21:53:02 jdolecek Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ext2fs_bswap.c,v 1.22 2016/08/04 17:43:48 jdolecek Exp $");
 
 #include <sys/types.h>
 #include <ufs/ext2fs/ext2fs.h>
@@ -117,7 +117,7 @@
        new->e2di_version       =       bswap32(old->e2di_version);
        new->e2di_gen           =       bswap32(old->e2di_gen);
        new->e2di_facl          =       bswap32(old->e2di_facl);
-       new->e2di_dacl          =       bswap32(old->e2di_dacl);
+       new->e2di_size_high     =       bswap32(old->e2di_size_high);
        new->e2di_nblock_high   =       bswap16(old->e2di_nblock_high);
        new->e2di_facl_high     =       bswap16(old->e2di_facl_high);
        new->e2di_uid_high      =       bswap16(old->e2di_uid_high);
diff -r 35b60e03d434 -r 8665c3c03168 sys/ufs/ext2fs/ext2fs_dinode.h
--- a/sys/ufs/ext2fs/ext2fs_dinode.h    Thu Aug 04 17:07:23 2016 +0000
+++ b/sys/ufs/ext2fs/ext2fs_dinode.h    Thu Aug 04 17:43:47 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: ext2fs_dinode.h,v 1.31 2016/08/04 04:05:14 nonaka Exp $        */
+/*     $NetBSD: ext2fs_dinode.h,v 1.32 2016/08/04 17:43:48 jdolecek Exp $      */
 
 /*
  * Copyright (c) 1982, 1989, 1993
@@ -123,7 +123,7 @@
                                        /* 40: disk blocks */
        uint32_t        e2di_gen;       /* 100: generation number */
        uint32_t        e2di_facl;      /* 104: file ACL (not implemented) (ext3) */
-       uint32_t        e2di_dacl;      /* 108: dir ACL (not implemented) (ext3) */
+       uint32_t        e2di_size_high; /* 108: Size (in bytes) high */
        uint32_t        e2di_obso_faddr;/* 112: obsolete fragment address (ext2) */
        uint16_t        e2di_nblock_high; /* 116: Blocks count bits 47:32 (ext4) */
        uint16_t        e2di_facl_high; /* 118: file ACL bits 47:32 (ext4) */
diff -r 35b60e03d434 -r 8665c3c03168 sys/ufs/ext2fs/ext2fs_inode.c
--- a/sys/ufs/ext2fs/ext2fs_inode.c     Thu Aug 04 17:07:23 2016 +0000
+++ b/sys/ufs/ext2fs/ext2fs_inode.c     Thu Aug 04 17:43:47 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: ext2fs_inode.c,v 1.83 2016/08/03 21:53:02 jdolecek Exp $       */
+/*     $NetBSD: ext2fs_inode.c,v 1.84 2016/08/04 17:43:48 jdolecek Exp $       */
 
 /*
  * Copyright (c) 1982, 1986, 1989, 1993
@@ -60,7 +60,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ext2fs_inode.c,v 1.83 2016/08/03 21:53:02 jdolecek Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ext2fs_inode.c,v 1.84 2016/08/04 17:43:48 jdolecek Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -104,7 +104,7 @@
        uint64_t size = ip->i_e2fs_size;
 
        if ((ip->i_e2fs_mode & IFMT) == IFREG)
-               size |= (uint64_t)ip->i_e2fs_dacl << 32;
+               size |= (uint64_t)ip->i_din.e2fs_din->e2di_size_high << 32;
        return size;
 }
 
@@ -113,7 +113,7 @@
 {
        if ((ip->i_e2fs_mode & IFMT) == IFREG ||
            ip->i_e2fs_mode == 0) {
-               ip->i_e2fs_dacl = size >> 32;
+               ip->i_din.e2fs_din->e2di_size_high = size >> 32;
                if (size >= 0x80000000U) {
                        struct m_ext2fs *fs = ip->i_e2fs;
 
diff -r 35b60e03d434 -r 8665c3c03168 sys/ufs/ufs/inode.h
--- a/sys/ufs/ufs/inode.h       Thu Aug 04 17:07:23 2016 +0000
+++ b/sys/ufs/ufs/inode.h       Thu Aug 04 17:43:47 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: inode.h,v 1.72 2016/06/03 15:36:03 christos Exp $      */
+/*     $NetBSD: inode.h,v 1.73 2016/08/04 17:43:48 jdolecek Exp $      */
 
 /*
  * Copyright (c) 1982, 1989, 1993
@@ -226,8 +226,6 @@
 #define        i_e2fs_rdev             i_din.e2fs_din->e2di_rdev
 #define        i_e2fs_gen              i_din.e2fs_din->e2di_gen
 #define        i_e2fs_facl             i_din.e2fs_din->e2di_facl
-#define        i_e2fs_dacl             i_din.e2fs_din->e2di_dacl
-#define        i_e2fs_faddr            i_din.e2fs_din->e2di_faddr
 #define        i_e2fs_nblock_high      i_din.e2fs_din->e2di_nblock_high
 #define        i_e2fs_facl_high        i_din.e2fs_din->e2di_facl_high
 #define        i_e2fs_uid_high         i_din.e2fs_din->e2di_uid_high



Home | Main Index | Thread Index | Old Index
diff -r 35b60e03d434 -r 8665c3c03168 sbin/newfs_ext2fs/mke2fs.c
--- a/sbin/newfs_ext2fs/mke2fs.c        Thu Aug 04 17:07:23 2016 +0000
+++ b/sbin/newfs_ext2fs/mke2fs.c        Thu Aug 04 17:43:47 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: mke2fs.c,v 1.23 2016/08/04 03:01:38 nonaka Exp $       */
+/*     $NetBSD: mke2fs.c,v 1.24 2016/08/04 17:43:47 jdolecek Exp $     */
 
 /*-
  * Copyright (c) 2007 Izumi Tsutsui.  All rights reserved.
@@ -100,7 +100,7 @@
 #if 0
 static char sccsid[] = "@(#)mkfs.c     8.11 (Berkeley) 5/3/95";
 #else
-__RCSID("$NetBSD: mke2fs.c,v 1.23 2016/08/04 03:01:38 nonaka Exp $");
+__RCSID("$NetBSD: mke2fs.c,v 1.24 2016/08/04 17:43:47 jdolecek Exp $");
 #endif
 #endif /* not lint */
 
@@ -1133,9 +1133,9 @@
                    "required to enable resize feature for this filesystem",
                    __func__);
        }
-       /* upper 32bit is stored into e2di_dacl on REV1 feature */
-       node.e2di_size = isize & UINT32_MAX;
-       node.e2di_dacl = isize >> 32;
+       /* upper 32bit is stored into e2di_size_high on REV1 feature */
+       node.e2di_size      = isize & UINT32_MAX;
+       node.e2di_size_high = isize >> 32;
 
 #define SINGLE 0       /* index of single indirect block */
 #define DOUBLE 1       /* index of double indirect block */